// $Id: ARPEncoding.java,v 1.3 2001/05/27 21:13:17 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.net;


/**
 * ARP protocol encoding information.
 * <p>
 * todo: the ARP protocol supports hardware types other than ethernet
 * and protocol types other than IP. this class isn't so generic yet.
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.3 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/05/27 21:13:17 $
 */
public class ARPEncoding
{
  /**
   * ARPPacket factory.
   */
  public static ARPPacket create(int lLen, byte [] bytes) {
    String sha = ARPEncoding.extractHwAddr(true, lLen, bytes);
    String dha = ARPEncoding.extractHwAddr(false, lLen, bytes);
    String spa = ARPEncoding.extractProtoAddr(true, lLen, bytes);
    String dpa = ARPEncoding.extractProtoAddr(false, lLen, bytes);
    int operation = ARPEncoding.extractOperation(lLen, bytes);

    return new ARPPacket(lLen, bytes, sha, dha, spa, dpa, operation);
  }

  /**
   * Extract the operation code from an ARP packet.
   */
  public static int extractOperation(int lLen, byte [] packetBytes) {
    return packetBytes[lLen + OP_POS] << 8 | packetBytes[lLen + OP_POS + 1];
  }

  /**
   * Extract a hardware (ARP) address from an ARP packet.
   * @param offset the offset of the address data from the start of the 
   * packet.
   * @param packetBytes packet bytes, including the link-layer header.
   */
  public static String extractHwAddr(boolean sourceFlag, 
                                     int lLen, 
                                     byte [] packetBytes) {
    int offset = sourceFlag ? lLen + S_HW_ADDR_POS : lLen + T_HW_ADDR_POS;
    return MACAddress.extract(offset, packetBytes);
  }

  /**
   * Extract a protocol (IP) address from an ARP packet.
   * @param offset the offset of the address data from the start of the 
   * packet.
   * @param packetBytes packet bytes, including the link-layer header.
   */
  public static String extractProtoAddr(boolean sourceFlag, 
                                        int lLen, 
                                        byte [] packetBytes) {
    int offset = sourceFlag ? lLen + S_PR_ADDR_POS : lLen + T_PR_ADDR_POS;
    return IPAddress.extract(offset, packetBytes);
  }


  /**
   * Position of the hardware address type.
   */
  public final static int HW_TYPE_POS = 0;

  /**
   * Position of the protocol address type.
   */
  public final static int PR_TYPE_POS = 2;

  /**
   * Position of the hardware address length.
   */
  public final static int HW_LEN_POS = 4;

  /**
   * Position of the protocol address length.
   */
  public final static int PR_LEN_POS = 5;

  /**
   * Position of the operation type.
   */
  public final static int OP_POS = 6;

  /**
   * Position of the sender hardware address.
   */
  public final static int S_HW_ADDR_POS = 8;

  /**
   * Position of the sender protocol address.
   */
  public final static int S_PR_ADDR_POS = S_HW_ADDR_POS + MACAddress.WIDTH;

  /**
   * Position of the target hardware address.
   */
  public final static int T_HW_ADDR_POS = S_PR_ADDR_POS + IPAddress.WIDTH;

  /**
   * Position of the target protocol address.
   */
  public final static int T_PR_ADDR_POS = T_HW_ADDR_POS + MACAddress.WIDTH;

  /**
   * Length in bytes of an ARP header.
   */
  public final static int HEADER_LEN = 8;


  private String _rcsid = 
    "$Id: ARPEncoding.java,v 1.3 2001/05/27 21:13:17 pcharles Exp $";
}
