// $Id: ICMPPacket.java,v 1.6 2001/05/28 18:30:12 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.net;

import net.ultrametrics.console.AnsiEscapeSequences;


/**
 * An ICMP packet.
 * <p>
 * Extends an IP packet, adding an ICMP header and ICMP data payload.
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.6 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/05/28 18:30:12 $
 */
public class ICMPPacket extends IPPacket 
{
  public ICMPPacket(int lLen, byte [] bytes,
                    String macSourceAddress, 
                    String macDestinationAddress, 
                    String sourceAddress, 
                    String destinationAddress,
                    int messageType) {
    super(lLen, bytes, 
          macSourceAddress, macDestinationAddress, 
          sourceAddress, destinationAddress, 
          IPProtocols.IPPROTO_ICMP);

    int offset = lLen + IPEncoding.HEADER_LEN;
    int headerLen = ICMPEncoding.HEADER_LEN;
    this.header = PacketEncoding.extractHeader(offset, headerLen, bytes);
    this.data = PacketEncoding.extractData(offset, headerLen, bytes);
    this.messageType = messageType;
  }

  /**
   * Fetch the icmp header, excluding icmp data payload.
   */
  public byte [] getHeader() {
    return header;
  }

  /**
   * Fetch data portion of the icmp header.
   */
  public byte [] getData() {
    return data;
  }

  /**
   * Convert this ICMP packet to a readable string.
   */
  public String toString() {
    StringBuffer buffer = new StringBuffer();
    buffer.append('[');
    buffer.append(AnsiEscapeSequences.LIGHT_BLUE);
    buffer.append("ICMPPacket");
    buffer.append(AnsiEscapeSequences.RESET);
    buffer.append(": ");
    buffer.append(ICMPMessage.getMessage(messageType));
    buffer.append(", ");
    buffer.append(sourceAddress + " -> " + 
                  destinationAddress);
    buffer.append(" l=" + header.length + "," + data.length);
    buffer.append(']');

    return buffer.toString();
  }


  /**
   * ICMP message type.
   */
  int messageType;

  /**
   * ICMP message type subcode.
   */
  int messageSubcode;

  /**
   * ICMP checksum.
   */
  int checksum;

  /**
   * ICMP header.
   */
  byte [] header;

  /**
   * ICMP data.
   */
  byte [] data;

  private String _rcsid = 
    "$Id: ICMPPacket.java,v 1.6 2001/05/28 18:30:12 pcharles Exp $";
}
