// $Id: PacketFactory.java,v 1.4 2001/05/25 13:57:11 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.net;


/**
 * This factory constructs high-level packet objects from
 * captured data streams.
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.4 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/05/25 13:57:11 $
 */
public class PacketFactory
{
  /**
   * Convert captured packet data into an object.
   */
  public static Packet dataToPacket(int linkType, byte [] bytes) {
    int typeCode;

    // if the link layer type is ethernet, extract the MAC information
    if(linkType == LinkLayers.DLT_EN10MB)
      typeCode = EthernetEncoding.extractTypeCode(bytes);
    else
      // assume IP. todo: this works for PPP, but probably not other LL's
      typeCode = EthernetProtocols.ETHERTYPE_IP;

    // record the length of the headers associated with this link layer type.
    // this length is the offset to the header embedded in the packet.
    lLen = LinkLayer.getLinkLayerLength(linkType);

    // try to recognize the ethernet type..
    switch(typeCode) {
      // arp
    case EthernetProtocols.ETHERTYPE_ARP: 
      return ARPEncoding.create(lLen, bytes);
    case EthernetProtocols.ETHERTYPE_IP:
      // ethernet level code is recognized as IP, figure out what kind..
      int ipProtocol = IPEncoding.extractProtocol(lLen, bytes);
      switch(ipProtocol) {
        // icmp
      case IPProtocols.IPPROTO_ICMP: return ICMPEncoding.create(lLen, bytes);
        // tcp
      case IPProtocols.IPPROTO_TCP: return TCPEncoding.create(lLen, bytes);
        // udp
      case IPProtocols.IPPROTO_UDP: return UDPEncoding.create(lLen, bytes);
        // unidentified ip..
      default: return IPEncoding.create(lLen, bytes);
      }
      // ethernet level code not recognized, default to anonymous packet..
    default: return EthernetEncoding.create(lLen, bytes);
    }
  }


  /**
   * Length in bytes of the link-level headers that this factory is 
   * decoding packets for.
   */
  private static int lLen;

  private String _rcsid = 
    "$Id: PacketFactory.java,v 1.4 2001/05/25 13:57:11 pcharles Exp $";
}
